/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.test.multicast;

import java.io.IOException;
import java.io.InputStream;

import jgroup.core.GroupManager;
import jgroup.core.JgroupException;
import jgroup.core.MemberId;
import jgroup.core.MembershipListener;
import jgroup.core.MembershipService;
import jgroup.core.View;
import jgroup.core.multicast.MulticastListener;
import jgroup.core.multicast.MulticastService;
import jgroup.util.Abort;

import org.apache.log4j.Logger;

public class Performer
implements MembershipListener, MulticastListener
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Logger
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Obtain logger for this class */
  private static Logger log = Logger.getLogger(Performer.class);


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Static fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Protocol name used to distinguish messages from other protocols. */
  private static final String PROTOCOL_NAME = "Performer";


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Exchanged message
  ////////////////////////////////////////////////////////////////////////////////////////////

  static byte[] data = new byte[51200*1];

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  GroupManager        gm;
  MembershipService   membershipService;
  MulticastService    multicastService;
  View                view;
  int                 counter;
  long                time;
  int                 me;

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  Performer()
        throws JgroupException, IOException
  {
    GroupManager gm = GroupManager.getGroupManager(this);
    membershipService = (MembershipService) gm.getService(MembershipService.class);
    multicastService = (MulticastService) gm.getService(MulticastService.class);
    membershipService.join(7);
    view = null;
    counter = 0;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Main method
  ////////////////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] argv)
    throws Exception
  {
    Performer t = new Performer();
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Upcalls
  ////////////////////////////////////////////////////////////////////////////////////////////

  public void viewChange(View view)
  {
    MemberId[] members = view.getMembers();

    time = System.currentTimeMillis();
    counter = 0;
    StringBuilder buf = new StringBuilder();
    buf.append("View: Vid");
    buf.append(view.getVid());
    buf.append(" Comp: ");
    for (int i=0; i < members.length; i++) {
      buf.append(members[i]);
      buf.append(", ");
    }
    log.debug(buf.toString());

    if (me == 0 && this.view == null) {
      this.view = view;
      try {
        data[0] = (byte) (System.currentTimeMillis() & 0xFF);
        data[data.length-1] = data[0];
        multicastService.mcast(PROTOCOL_NAME, data, null);
      } catch (Exception e) {
        Abort.exit("Mcast exception", e, 1);
      }
    }
  }

  /**
   *  Returns a string naming the protocol implemented by this multicast
   *  listener.
   */
  public String getProtocolName() 
  {
    return PROTOCOL_NAME;
  }

  public Object deliverStream(InputStream stream, MemberId sender, int seqNo)
  {
    return null;
  }


  public Object deliverObject(Object msg, MemberId sender, int seqNo)
  {
    byte[] data = (byte[]) msg;

    log.debug("+");
    if (me == 0) {
      try {
        data[0] = (byte) (System.currentTimeMillis() & 0xFF);
        data[data.length-1] = data[0];
        multicastService.mcast(PROTOCOL_NAME, data, null);
      } catch (Exception e) {
        Abort.exit("Mcast exception", e, 1);
      }
    }
    counter++;
    if (counter % 100 == 0)
      log.debug("\nMessages: " + counter + " Msg/sec: " + (float) counter / ((System.currentTimeMillis()-time)/1000));
    return null;
  }


  public void prepareChange()
  {
  }


  public void hasLeft()
  {
  }

}
