/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.test.performance;

import java.io.FileOutputStream;
import java.io.PrintWriter;

import jgroup.core.registry.DependableRegistry;
import jgroup.core.registry.RegistryFactory;
import jgroup.util.Network;
import jgroup.util.Util;

/**
 *  Test for measuring the performance of GMI invocations.
 *  Can be executed remotely through the <t>Executor</t> class,
 *  since it implements the <t>Server</t> interface.
 *
 *  @author       Alberto Montresor
 *  @since        Jgroup 1.1
 */
public class SpeedTestClient
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Main
  ////////////////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] argv)
    throws Exception
  {
    SpeedTestClient client = new SpeedTestClient();
    client.start();
  }

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** True when the action requested is completed */
  private boolean completed = false;

  
  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructor
  ////////////////////////////////////////////////////////////////////////////////////////////

  public SpeedTestClient()
  {
  }

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////

  public synchronized void start()
    throws Exception
  {
    DependableRegistry reg = RegistryFactory.getRegistry();
    SpeedTest test = (SpeedTest) reg.lookup("Jgroup/SpeedTest");

    // Open log file
    PrintWriter out = null;
    try {
      StringBuilder buffer = new StringBuilder();
      buffer.append("log-");
      buffer.append(Network.getLocalHostName());
      buffer.append("-");
      buffer.append(Util.getDateTimeString());
      buffer.append(".txt");
      out = new PrintWriter(new FileOutputStream(buffer.toString()));
    } catch (Exception e) {
      e.printStackTrace();
    }

    // Perform test
//    ClientTest.test1(test, out);
//    ClientTest.test2(test, out);
//    ClientTest.mtest1(test, out);
    ClientTest.mtest2(test, out);
    ClientTest.mtest3(test, out);
    ClientTest.mtest4(test, out);

    completed = true;
    notify();
  }

  public synchronized void halt()
    throws Exception
  {
    while (!completed)
      try { wait(); } catch (Exception e) { }
  }

} // END SpeedTestClient
