/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.test.performance.upgrade;



/**
 *  This class supports command line parameter parsing. In the future, 
 *  it should be replaced by a more powerful standard framework for 
 *  command line parameter parsing. 
 *
 *  @author Marcin Solarski
 *  @since Jgroup 2.1
 */

class PUtil {

 /**
   * method parses the string array with tokenized parameters.
   * @param argv the string array with parameters
   * @param name the parameter name
   * @param defValue the default value of the parameter
   * @return value of the parameter following one with a given name 
   * or its default value. If the default value is not convertable to
   * int the method returns 0.
   */
  static int getIntParameter(String argv[], String name, String defValue) {
    int dv = 0;
    try {
      dv =  Integer.parseInt(defValue);
      for(int i=0; i<argv.length; i++){
      if( argv[i] != null && argv[i] != null && argv[i].compareTo(name) == 0) {
         String val = "1";
         if( i+1<argv.length ) val = argv[i+1];
         try{ return Integer.parseInt(val); }
         catch(NumberFormatException e) { return dv;}
      }
      }
    } catch(NumberFormatException e) { return 0;}
    return dv;
  }

  
  /**
   * method parses the string array with tokenized parameters.
   * @param argv the string array with parameters
   * @param name the parameter name
   * @param defValue the default value of the parameter
   * @return string value of the parameter following one with a given name 
   * or its default value if the name is not given in the command line. 
   */
  static String getStringParameter(String argv[], String name, String defValue) {
    String val = null;
    for(int i=0; i<argv.length; i++){
        if( argv[i] != null && argv[i] != null && argv[i].compareTo(name) == 0) {
           if( i+1<argv.length ) val = argv[i+1]; else val = defValue;
	   return val;
	}
    }
    return defValue;
  }

 /**
  * parses a switch kind of command line parameter
  * @param name the switch name 
  * @return true if the switch is found in the command line
  */
  static boolean getSwitch(String argv[], String name) {
    for(int i=0; i<argv.length; i++)
        if( argv[i] != null && argv[i].compareTo(name) == 0) 
	   return true;
    return false;
  }
}
