/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.arm;

import java.util.Enumeration;
import java.util.StringTokenizer;

import jgroup.core.ConfigManager;
import jgroup.core.arm.ExecService;
import jgroup.core.registry.BootstrapRegistry;

/**
 * Shutdown the execution service on the given host.
 * 
 * @author Hein Meling
 * @since Jgroup 2.1
 */
public class ShutdownHost
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Main method
  ////////////////////////////////////////////////////////////////////////////////////////////

  public static void main(String[] args)
    throws Exception
  {
    ConfigManager.init();
    String hosts = System.getProperty("jgroup.shutdown.hosts");
    if (hosts == null || hosts.length() == 0) {
      throw new IllegalArgumentException("No hosts specified for shutdown");
    }
    Enumeration hostsEnum = new StringTokenizer(hosts, ",");
    int delay = 0;
    while (hostsEnum.hasMoreElements()) {
      String host = (String) hostsEnum.nextElement();
      System.out.println("Shutdown: " + host);
      ExecService es = (ExecService) BootstrapRegistry.lookup(host, ExecService.EXEC_DAEMON_NAME);
      es.shutdown(delay);
      delay += 200;
    }
    System.exit(0);
  }

} // END ShutdownHost
