/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core;

/**
 * When performing an asynchronous internal group method invocation (IGMI),
 * an invoker may specify a callback object. The task of this callback object
 * is to collect regular values and exceptions returned by members executing
 * the asynchronous IGMI. <p>
 *
 * For each of the members contained in the view in which the invocation is
 * executed, methods <tt>result</tt> or <tt>exception</tt> are invoked on the
 * callback object. If a member becomes unreachable before being able to return
 * a value or an exception to the invoker, then the callback object is notified
 * through the invocation of method <tt>exception</tt> with a
 * <tt>RemoteException</tt> as argument. Otherwise, the regular value or the
 * exception is communicated to the callback object through the invocation
 * of methods <tt>result</tt> or <tt>exception</tt>. <p>
 *
 * In both these methods, the identifier of the member returning the value or
 * the exception is provided. On the other hand, no invocation identifier is
 * provided. If the invoker need to distinguish return values associated to
 * distinct exceptions, distinct callback objects should be used.
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.8
 */
public interface  Callback
{

  /**
   * Invoked by internal GMI service to notify this callback object that
   * the member identified by <tt>MemberId</tt> has returned <tt>result</tt>.
   *
   * @param id      the member identifier
   * @param result  the regular value returned by the asynchronous invocation
   */
  public void result(MemberId id, Object result);


  /**
   * Invoked by internal GMI service to notify this callback object that
   * the member identified by <tt>MemberId</tt> has thrown <tt>e</tt>.
   *
   * @param id    the member identifier
   * @param e     the exception thrown by the asynchronous invocation
   */
  public void exception(MemberId id, Exception e);


} // END Callback
