/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core;

import org.apache.log4j.Logger;

/**
 *  Base class for the exceptions thrown by Jgroup.
 *
 *  @author Alberto Montresor
 *  @since Jgroup 0.1
 */
public class JgroupException
  extends Exception
{

  private static final long serialVersionUID = 19163829929627863L;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Logger
  ////////////////////////////////////////////////////////////////////////////////////////////

  /** Obtain logger for this class */
  private static final Logger log = Logger.getLogger(JgroupException.class);


  /**
   *  Constructs a <code>JgroupExeception</code> with the specified
   *  message.
   *
   *  @param message
   *    Detailed message describing the problem.
   */
  public JgroupException(String message)
  {
    super(message);
    synchronized (this) {
      log.warn(message);
    }
  }

  /**
   *  Constructs a <code>JgroupExeception</code> with the specified
   *  message and cause exception.
   *
   *  @param message
   *    Detailed message describing the problem.
   *  @param cause
   *    The cause exception.
   */
  public JgroupException(String message, Throwable cause)
  {
    super(message, cause);
    synchronized (this) {
      log.warn(message, cause);
    }
  }

} // END JgroupException
