/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core;

/**
 *  In order to be notified of state merging events, an object must
 *  implement this interface.  Two methods are declared; the first,
 *  <code>getState</code>, is invoked when the member has been selected
 *  as coordinator for the reconciliation protocol.  As coordinator, the
 *  member must prepare a status message containing the information
 *  needed by members that needs to be updated with the state maintained
 *  by servers in the partition of the coordinator.  The method
 *  <code>putState</code> is invoked to inform the member about the
 *  state of other members belonging to different partitions.
 *
 *  @author Alberto Montresor
 *  @since 0.7
 */
public interface MergingListener
{

  /**
   *  Method <code>getState</code> is invoked when the member has been
   *  selected as coordinator for the reconciliation protocol.
   *
   *  @param dests
   *    The destination set of the reconciliation message;
   *  @return 
   *    The reconciliation message
   */
  public Object getState(MemberId[] dests);


  /**
   *  Method <code>putState</code> is invoked to inform the member about
   *  the state of other members belonging to different partitions.
   *
   *  @param status
   *    The reconciliation message
   *  @param sources
   *    The state contained in <code>status</code> is already known by
   *    members in <code>sources</code>.
   */
  public void putState(Object status, MemberId[] sources);

} // END MergingListener
