/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core;

import java.net.InetAddress;
import java.net.UnknownHostException;

/**
 *  The purpose of the <code>VMID</code> interface is to uniquely
 *  identify a Java Virtual Machine.  Each <code>VMID</code> instance is
 *  composed by an IP address and an incarnation time.
 *
 *  @author Alberto Montresor
 *  @since Jgroup 0.7
 */
public interface VMID
  extends java.io.Externalizable
{

  /**
   *  Returns the IP address of the host on which the virtual machine
   *  identified by this <code>VMID</code> is being executed.
   */
  public InetAddress getAddress()
    throws UnknownHostException;


  /**
   *  Returns the time at which this <code>VMID</code> has been created.
   */
  public long getTime();

} // END VMID
