/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core.arm;

import java.io.Externalizable;


/**
 *  Event types implementing the <code>ARMEvent</code> interface may be
 *  passed to the replication manager to notify it of certain events.
 *  The event itself must provide the <code>handle()</code> method,
 *  enabling the replication manager to invoke the event handler.  That
 *  is, events provide self-handling.  <p>
 *
 *  Note that events must also implement the <code>Externalizable</code>
 *  interface.
 *
 *  @see jgroup.arm.EDPresentEvent
 *  @see jgroup.arm.ViewChangeEvent
 *  @see jgroup.arm.ReplicaPingEvent
 *  @author Hein Meling
 *  @since Jgroup 1.2
 */
public interface ARMEvent
  extends Externalizable
{

  /**
   *  This method must implement the actual handling of the event, as
   *  recevied by the replication manager.
   *
   *  @param distScheme
   *    access point to the replication manager for external events
   * 
   */
  public void handle(DistributionScheme distScheme)
    throws Exception;

  /**
   *  Returns the groupd identifier associated with this event.
   *  If the event is not associated with any group, it should
   *  return -1.
   */
  public int getGroupId();

  /**
   *  Retreive an object associated with this event.  This method may
   *  return <code>null</code> if the event internals need not or should
   *  not be exposed externally.
   */
  public Object getObject();

} // END ARMEvent
