/*
 * Copyright (c) 1998-2004 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.core.registry;

import java.io.IOException;
import java.rmi.AccessException;
import java.rmi.NotBoundException;
import java.rmi.Remote;
import java.rmi.RemoteException;

import jgroup.core.JgroupException;
import jgroup.core.Layer;

/**
 * Service interface for performing lookups from a replicated
 * client group.  This service must be used for client groups
 * to ensure that proxies downloaded to client group members
 * are correctly initialized with the important group manager
 * information required to suppress duplicates from the clients
 * at the server-side.  That is, the proxy needs access to the
 * <code>TimestampService</code>.
 *
 * @author Hein Meling
 */
public interface LookupService
  extends Layer
{

  /**
   * Returns a proxy for the remote object group associated with
   * the specified name.
   *
   * @param name
   *   The name associated with the remote object group.
   * @return
   *   A proxy for the remote object group.
   *
   * @exception RemoteException
   *   If remote operation failed.
   * @exception JgroupException
   *   If the dependable registry could not be found.
   * @exception NotBoundException
   *   If there is no object group with this name in the registry/reggie.
   * @exception AccessException
   *   If this operation is not permitted.
   */
  public Remote lookup(String name)
    throws RemoteException, JgroupException, NotBoundException, AccessException;

  /**
   * Returns a proxy for the remote object group associated with 
   * the specified name and class in greg. 
   *  
   * @param name
   *   The name associated with the remote object group.
   * @param clas
   *   The class associated with the remote object group.
   * @return
   *   A proxy for the remote object group.
   * 
   * @exception IOException
   *   If an error occured during lookup.
   */
  public Object lookup(String name, Class clas)
    throws IOException;

} // END LookupService
