/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.daemon;

/**
 * The <code> Tag</code> interface contains the tags internally used by daemons
 * and members to communicate.
 *
 * @author  Alberto Montresor
 * @since   Jgroup 0.1
 */
interface Tag
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Status tags
  ////////////////////////////////////////////////////////////////////////////////////////////

  static final int S_IDLE       = 1;    // Idle phase
  static final int S_SYNCH      = 2;    // Synchronization phase
  static final int S_ESTIMATE   = 3;    // Estimate exchange phase

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Remote messages tags (group-related messages)
  ////////////////////////////////////////////////////////////////////////////////////////////

  static final byte R_MCAST     = 1;            // Multicast messages
  static final byte R_ACK       = 2;            // Interested message
  static final byte R_ESTIM     = 3;            // Estimate
  static final byte R_FORWARD   = 4;            // Delivered message
  static final byte R_SYNCH     = 5;            // Synchronization message
  static final byte R_SYMM      = 6;            // Symmetry message
  static final byte R_PROP      = 7;            // Propose message
  static final byte R_VIEW      = 8;            // New view
  static final byte R_RESULT    = 9;            // Result message


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Minimal tag for group unrelated messages
  ////////////////////////////////////////////////////////////////////////////////////////////

  static final byte R_NOGID     = 100;          // Minimal tag for group unrelated messages


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Remote messages tags (group-unrelated messages)
  ////////////////////////////////////////////////////////////////////////////////////////////

  static final byte R_INTEREST  = 101;          // Interested message
  static final byte R_NOINTEREST= 102;          // Interested message
  static final byte R_LEAVE     = 102;          // Leave message
  static final byte R_JOIN      = 103;          // Join message
  static final byte R_JOINACK   = 104;          // Join ack message

  static final String R_TAGS[] = {"invalid", "R_MCAST", "R_ACK", "R_ESTIM", "R_FORWARD", 
	                          "R_SYNCH", "R_SYMM", "R_PROP", "R_VIEW", "R_RESULT" };

  static final String R_ExTAGS[] = { "R_NOGID", "R_INTEREST", "R_LEAVE", 
	  			     "R_JOIN", "R_JOINACK"};

} // END Tag
