/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.events;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;

import jgroup.core.MemberId;
import jgroup.relacs.types.MemberIdImpl;

/**
 *  The <code>LeaveRequest</code> class represents a local message
 *  exchange between members and the daemon; it is used by the member to
 *  notify the daemon of a leave request from the specified member.
 *
 *  @author Alberto Montresor
 *  @since Jgroup 1.2
 */
public final class LeaveRequest
  extends Event
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Fields
  ////////////////////////////////////////////////////////////////////////////////////////////

  private static final long serialVersionUID = -2658734788834444617L;

  /** Local member identifier */
  private MemberId memberId;


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constructors
  ////////////////////////////////////////////////////////////////////////////////////////////

  /**
   *  Default constructor for externalization.
   */
  public LeaveRequest()
  {
  }

  /**
   *  Create a <code>LeaveRequest</code> for the specified member of
   *  group <code>gid</code>.
   */
  public LeaveRequest(int gid, MemberId memberId)
  {
    super(LEAVE_REQUEST, gid);
    this.memberId = memberId;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Returns the member identifier for the leaving member.
   */
  public MemberId getMemberId()
  {
    return memberId;
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Externalizable
  ////////////////////////////////////////////////////////////////////////////////////////////
  
  /**
   *  Restores the content of this object from the marshalled data contained
   *  in the specified input stream.
   * 
   *  @param in the stream to be read
   */
  public void readExternal(ObjectInput in)
    throws IOException, ClassNotFoundException
  {
    super.readExternal(in);
    memberId = new MemberIdImpl();
    memberId.readExternal(in);
  }
  
  /**
   *  Marshals the content of this object to the specified output stream.
   * 
   *  @param out the stream to be written
   */
  public void writeExternal(ObjectOutput out)
    throws IOException
  {
    super.writeExternal(out);
    memberId.writeExternal(out);
  }


  ////////////////////////////////////////////////////////////////////////////////////////////
  // Methods from Object
  ////////////////////////////////////////////////////////////////////////////////////////////

  public String toString()
  {
    StringBuilder buf = new StringBuilder();
    buf.append(super.toString());
    buf.append("[LeaveRequest: memberId=");
    buf.append(memberId);
    buf.append("]");
    return buf.toString();
  }

} // END LeaveRequest
