/*
 * Copyright (c) 1998-2004 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */
package jgroup.relacs.gmi;

import java.rmi.Remote;
import java.rmi.server.ExportException;

import jgroup.core.ExternalGMIService;
import jgroup.core.GroupManager;
import jgroup.relacs.config.AppConfig;
import net.jini.export.Exporter;


/**
 * This class can be used together with Jini2 config files
 * to export a proxy. It uses <code>JeriEGMILayer</code> as 
 * the invocation factory. 
 * 
 * @author Rohnny Moland
 */
public class JeriGroupExporter implements Exporter
{
  /** Service proxy **/
  private ExternalGMIService externalGMIService;

  /**
   * Obtains a <code>GroupManager</code> from the application
   * name, and an <code>ExternalGMIService</code>.
   * 
   * @param name the application name
   */
  public JeriGroupExporter(String name) 
  {
    AppConfig app = AppConfig.getApplication(name);
    int gid = app.getGroupId();   
    GroupManager gm = GroupManager.getGroupManager(gid);
    externalGMIService = (ExternalGMIService) gm.getService(ExternalGMIService.class);
  }

  /* (non-Javadoc)
   * @see net.jini.export.Exporter#export(java.rmi.Remote)
   */
  public Remote export(Remote impl) 
    throws ExportException
  {
    return externalGMIService.getProxy(impl); 
  }

  /* (non-Javadoc)
   * @see net.jini.export.Exporter#unexport(boolean)
   */
  public boolean unexport(boolean force) 
  {
    return false;
  }
}
