/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.mss;

import jgroup.core.EndPoint;

/**
 *  The <code>NetworkInterface</code> interface.
 *
 *  @author Salvatore Cammarata
 *  @author Hein Meling
 *  @since Jgroup 1.2
 */
public interface NetworkInterface
{

  /**
   *  Send a datagram packet to the local cluster.
   *
   *  @param buffer
   *    An array of bytes containing the packet to send.
   *  @param buflen
   *    The actual packet length
   */
  public void send(byte[] buffer, int blen);

  /**
   *  Send a datagram packet to the specified destination
   *  <code>EndPoint</code>.
   *
   *  @param dest
   *    The destination <code>EndPoint</code>.
   *  @param buffer
   *    An array of bytes containing the packet to send.
   *  @param buflen
   *    The actual packet length
   */
  public void send(EndPoint dest, byte[] buffer, int buflen);

  /**
   *  Start the network interface 
   */
  public void doStart();

  /**
   *  Stop the network interface 
   */
  public void doStop();

} // END NetworkInterface
