/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.simulator;

import java.rmi.RemoteException;
import java.util.Iterator;

import jgroup.core.ConfigManager;
import jgroup.core.ConfigurationException;
import jgroup.relacs.config.DistributedSystemConfig;
import jgroup.relacs.config.Domain;
import jgroup.relacs.config.DomainSet;
import jgroup.relacs.config.Host;
import jgroup.relacs.config.HostSet;

/**
 *  Partition simulator that will examine domains, and generate partitions
 *  between domains and reconnect them as instructed through commandline
 *  arguments.
 *
 *  @author  Hein Meling
 *  @since   Jgroup 2.1
 */
public class PartitionSimulator
{

  public static void main(String[] argv)
  {
    if (argv.length == 0)
      throw new IllegalArgumentException("Wrong number of arguments");
    int reachability = Integer.parseInt(argv[0]);
    System.out.println("Domain reachability=" + reachability);
    try {
      ConfigManager.init();
    } catch (ConfigurationException e) {
      e.printStackTrace();
    }
    DistributedSystemConfig dsc = ConfigManager.getDistributedSystem();
    DomainSet domains = dsc.getDomainSet();
    for (Iterator<Domain> iter = domains.iterator(); iter.hasNext();) {
      Domain domain = iter.next();
      for (Iterator<Domain> iterator = domains.iterator(); iterator.hasNext();) {
        Domain otherDomain = iterator.next();
        if (!domain.equals(otherDomain)) {
          setReachability(reachability, domain, otherDomain);
        }
      }
      HostSet d1Hosts = domain.getHostSet();
      for (Iterator<Host> i = d1Hosts.iterator(); i.hasNext();) {
        Host host = i.next();
        try {
          ((SocketStatus) host.get("SocketStatus")).commit();
        } catch (RemoteException e) {
          e.printStackTrace();
        }
      }
    }
  }

  private static void setReachability(int reachability, Domain d1, Domain d2)
  {
    HostSet d1Hosts = d1.getHostSet();
    for (Iterator<Host> iter = d1Hosts.iterator(); iter.hasNext();) {
      Host h1 = iter.next();
      System.out.print(h1.getHostName() + "(" + reachability + "): ");
      try {
        SocketStatus status = (SocketStatus) h1.lookup("SocketStatus");
        h1.put("SocketStatus", status);
        for (Iterator<Host> iterator = d2.getHostSet().iterator(); iterator.hasNext();) {
          Host h2 = iterator.next();
          status.setStatus(h2.getAddress(), reachability);
          System.out.print(h2.getHostName() + " ");
        }
        System.out.println();
      } catch (Exception e) {
        iter.remove();
        System.out.println(h1.getHostName() + " is not available");
      }
    }
  }

} // END of PartitionSimulator
