/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.relacs.simulator;

import java.io.BufferedReader;
import java.io.FileReader;
import java.net.InetAddress;
import java.util.ArrayList;
import java.util.Iterator;
import java.util.List;

import jgroup.core.ConfigManager;
import jgroup.core.registry.BootstrapRegistry;

/**
 *  Parser for the partition simulator files.  The file format is as follows:
 * 
 *  <pre>
 *    hostname  link-to-host  probability-of-link-working  link-to-host  prob ...
 *  </pre>
 *
 *  @author  Alberto Montresor
 *  @author  Hein Meling
 *  @since   Jgroup 0.5
 */
public class Simulator
{

  ////////////////////////////////////////////////////////////////////////////////////////////
  // Constants
  ////////////////////////////////////////////////////////////////////////////////////////////


  public static void main(String[] argv)
  {
    InetAddress         inet;
    int                 prob;
    SocketStatus        status;

    try {
      ConfigManager.init();
      if (argv.length == 0)
        throw new IllegalArgumentException("Wrong number of arguments");
      BufferedReader in = new BufferedReader(new FileReader(argv[0]));
      String line = null;
      int start, stop;
      List<SocketStatus> hosts = new ArrayList<SocketStatus>(20);
      while ((line = in.readLine()) != null) {
        start = 0;
        stop = line.indexOf(" ", start); stop = (stop >= 0 ? stop : line.length());
        String hostname = line.substring(start, stop);
        if (hostname.startsWith("#")) {
          // Ignore commented lines
          continue;
        }
        System.out.print(hostname + ": ");
        try {
          status = (SocketStatus) BootstrapRegistry.lookup(hostname, "SocketStatus");
          hosts.add(status);
          while (stop < line.length()) {
            start = stop+1;
            stop  = line.indexOf(" ", start); stop = (stop >= 0 ? stop : line.length());
            String linkTo = line.substring(start, stop);
            inet  = InetAddress.getByName(linkTo);
            start = stop+1;
            stop  = line.indexOf(" ", start); stop = (stop >= 0 ? stop : line.length());
            prob  = Integer.parseInt(line.substring(start, stop));
            status.setStatus(inet, prob);
            System.out.print(" link-to " + linkTo + "(" + prob + ")  ");
          }
          System.out.println();
        } catch (java.lang.Exception e) {
//          e.printStackTrace();
          System.out.println(" Not available: " + hostname);
        }
      }
      for (Iterator<SocketStatus> iter = hosts.iterator(); iter.hasNext();) {
        status = iter.next();
        status.commit();
      }
    } catch (IllegalArgumentException e) {
      System.out.println(e.getMessage());
      System.out.println("Usage: simulator <partition-file>");
    } catch (Exception e) {
      e.printStackTrace();
    }
  }

} // END of Simulator
