/*
 * Copyright (c) 1998-2002 The Jgroup Team.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License version 2 as
 * published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 */

package jgroup.upgrade;

import java.rmi.RemoteException;

import jgroup.core.arm.ReplicationManager;
import jgroup.core.registry.DependableRegistry;
import jgroup.core.registry.RegistryFactory;
import jgroup.relacs.config.AppConfig;
import jgroup.util.Abort;

/**
 *  Client program for accessing the <code>UpgradeManager</code>.
 *
 *  @author Hein Meling
 *  @since Jgroup 1.2
 */
public class UpgradeManagementClient {

	public static void main(String argv[]) throws Exception {

		/* parse params */
		boolean create_cmd = true;
		boolean remove_cmd = true;
		boolean wait_cmd = true;
		boolean test_cmd = false;
		boolean upgrade_cmd = false;
		boolean list_cmd = false;
		String cmd = "uwc";
		if (argv.length > 0 && argv[0] != null)
			cmd = argv[0];
		System.out.println("Got the following params: " + cmd);

		if (cmd.indexOf('c') >= 0)
			create_cmd = true;
		else
			create_cmd = false;
		if (cmd.indexOf('r') >= 0)
			remove_cmd = true;
		else
			remove_cmd = false;
		if (cmd.indexOf('w') >= 0)
			wait_cmd = true;
		else
			wait_cmd = false;
		if (cmd.indexOf('t') >= 0)
			test_cmd = true;
		else
			test_cmd = false;
		if (cmd.indexOf('u') >= 0)
			upgrade_cmd = true;
		else
			upgrade_cmd = false;
		if (cmd.indexOf('l') >= 0)
			list_cmd = true;
		else
			list_cmd = false;

		/*
		 * Obtain a proxy for the depedable registry running in the
		 * distributed system described in the config.xml file.
		 */
		DependableRegistry dregistry = RegistryFactory.getRegistry();

		/*
		 * Retrieve a proxy for an object group implementing the
		 * ReplicationManager interface registered under the name
		 * "ReplicationManager".
		 */
		ReplicationManager replicaManager =
			(ReplicationManager) dregistry.lookup("Jgroup/ReplicationManager");
		System.out.println("Successful lookup: ReplicationManager");

		AppConfig app = null;
//    AppConfig app = AppConfig.getApplication(jgroup.test.performance.upgrade.UpgradeServer.class);

		if (create_cmd) {
			try {
				System.out.println("Creating group: " + app);
				replicaManager.createGroup(app);
			} catch (Exception exception) {
				throw new Abort("Failed to create the upgrade server group", exception);
			}
			System.out.println(
				"The group with upgradable servers is successfully created!");
		}

		if (remove_cmd) {
			try {
				System.out.println("Removing group: " + app);
				replicaManager.removeGroup(app);
			} catch (Exception exception) {
				throw new Abort("Failed to remove the upgrade server group", exception);
			}
			System.out.println(
				"The group with upgradable servers is successfully removed!");

		}


		if (wait_cmd) {
			System.out.println("Watining 30 sec to send an upgrade request");

			/* Sleep for 10 seconds before upgrading */
			try {
				Thread.sleep(30000);
			} catch (InterruptedException ex) {
			}
		}

		if (list_cmd) {
			try {
				DependableRegistry reg = RegistryFactory.getRegistry();
				String objs[] = reg.list();
				System.out.println("The following entries in DRegistry:");
				for(int i=0; i< objs.length; i++) 
				  System.out.println("[" +i+ "]: " + objs[i]);
				System.out.println("=============");				  
			} catch (RemoteException ex) {
				throw new Abort("Am upgrade server test failed ", ex);
			}
		}


		if (test_cmd) {
			try {
				System.out.println("Trying to getthe Registry ");
				DependableRegistry reg = RegistryFactory.getRegistry();
				System.out.println("Trying to lookup UpgradeServer");
//				SpeedTest u_serv =
//					(SpeedTest) reg.lookup("UpgradeServer");
//
//				System.out.println("Testing the upgrade server ");
//				String r_val = u_serv.mtest("Testing");
//				if (r_val.compareTo( "Testing" ) == 0)
//          System.out.println("Test ok.");
//				else
//          System.out.println("Test wrong: the server returns unexpcected value: " + r_val);				
			} catch (RemoteException ex) {
				throw new Abort("Am upgrade server test failed ", ex);
			}
		}


		if (upgrade_cmd) {

			UpgradeManager upgrManager =
				(UpgradeManager) dregistry.lookup("Jgroup/UpgradeManager");
//			app = AppConfig.getApplication(jgroup.test.performance.upgrade.UpgradeServer2.class);
			long start = 0; 
			long utp = 0;
			try {
				System.out.println("Upgrading group: " + app);
				start = System.currentTimeMillis();
				upgrManager.upgradeGroup(app);
				utp = System.currentTimeMillis() - start;
				System.out.println("Server upgraded, UTP = " + utp);
			} catch (Exception exception) {
				utp = System.currentTimeMillis() - start;
				System.out.println("Server upgrade FAILED, exception thrown after time = " + utp);
				throw new Abort("Failed to create upgrserver", exception);
			}
		}
	}

} // END UpgradeManagementClient
