/*
 * Copyright 1999,2004 The Apache Software Foundation.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *      http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package jgroup.util;

import org.apache.log4j.ULogger;
import org.apache.log4j.pattern.LoggingEventPatternConverter;
import org.apache.log4j.spi.LoggingEvent;

/**
 * Return the events thread (usually the current thread) in a StringBuffer.
 * This buffer is recycled!
 * 
 * @author Ceki G&uuml;lc&uuml;
 * @author Hein Meling
 */
public class ThreadIdPatternConverter 
  extends LoggingEventPatternConverter 
{

  /**
   * Singleton.
   */
  private static final ThreadIdPatternConverter INSTANCE =
    new ThreadIdPatternConverter();

  /**
   * private constructor
   */
  private ThreadIdPatternConverter() 
  {
    super("tid", "tid");
  }

  /**
   * Obtains an instance of ThreadIdPatternConverter.
   * @param options
   * @param logger
   * @return
   */
  public static ThreadIdPatternConverter newInstance(
      final String[] options, final ULogger logger) {
      return INSTANCE;
    }
  
  /* (non-Javadoc)
   * @see org.apache.log4j.pattern.LoggingEventPatternConverter#format(
   * org.apache.log4j.spi.LoggingEvent, java.lang.StringBuffer)
   */
  @Override
  public void format(LoggingEvent event, StringBuffer toAppendTo)
  {
    toAppendTo.append(Thread.currentThread().getId());
  }

} // END ThreadIdPatternConverter
